@@ -1,28 +1,26 @@
-/* 
+/*
  * tkAtom.c --
  *
- *	This file manages a cache of X Atoms in order to avoid
- *	interactions with the X server.  It's much like the Xmu
- *	routines, except it has a cleaner interface (caller
- *	doesn't have to provide permanent storage for atom names,
- *	for example).
+ *	This file manages a cache of X Atoms in order to avoid interactions
+ *	with the X server. It's much like the Xmu routines, except it has a
+ *	cleaner interface (caller doesn't have to provide permanent storage
+ *	for atom names, for example).
  *
  * Copyright (c) 1990-1994 The Regents of the University of California.
  * Copyright (c) 1994 Sun Microsystems, Inc.
  *
- * See the file "license.terms" for information on usage and redistribution
- * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
+ * See the file "license.terms" for information on usage and redistribution of
+ * this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
-#include "tkPort.h"
 #include "tkInt.h"
 
 /*
- * The following are a list of the predefined atom strings.
- * They should match those found in xatom.h
+ * The following are a list of the predefined atom strings. They should match
+ * those found in xatom.h
  */
 
-static CONST char *atomNameArray[] = {
+static char * atomNameArray[] = {
     "PRIMARY",		"SECONDARY",		"ARC",
     "ATOM",		"BITMAP",		"CARDINAL",
     "COLORMAP",		"CURSOR",		"CUT_BUFFER0",
@@ -46,24 +44,24 @@ static CONST char *atomNameArray[] = {
     "COPYRIGHT",	"NOTICE",		"FONT_NAME",
     "FAMILY_NAME",	"FULL_NAME",		"CAP_HEIGHT",
     "WM_CLASS",		"WM_TRANSIENT_FOR",
-    (char *) NULL
+    NULL
 };
 
 /*
- * Forward references to procedures defined in this file:
+ * Forward references to functions defined in this file:
  */
 
-static void	AtomInit _ANSI_ARGS_((TkDisplay *dispPtr));
+static void	AtomInit(TkDisplay *dispPtr);
 
 /*
  *--------------------------------------------------------------
  *
  * Tk_InternAtom --
  *
- *	Given a string, produce the equivalent X atom.  This
- *	procedure is equivalent to XInternAtom, except that it
- *	keeps a local cache of atoms.  Once a name is known,
- *	the server need not be contacted again for that name.
+ *	Given a string, produce the equivalent X atom. This function is
+ *	equivalent to XInternAtom, except that it keeps a local cache of
+ *	atoms. Once a name is known, the server need not be contacted again
+ *	for that name.
  *
  * Results:
  *	The return value is the Atom corresponding to name.
@@ -75,29 +73,28 @@ static void	AtomInit _ANSI_ARGS_((TkDisplay *dispPtr));
  */
 
 Atom
-Tk_InternAtom(tkwin, name)
-    Tk_Window tkwin;		/* Window token;  map name to atom
-				 * for this window's display. */
-    CONST char *name;		/* Name to turn into atom. */
+Tk_InternAtom(
+    Tk_Window tkwin,		/* Window token; map name to atom for this
+				 * window's display. */
+    CONST char *name)		/* Name to turn into atom. */
 {
     register TkDisplay *dispPtr;
     register Tcl_HashEntry *hPtr;
-    int new;
+    int isNew;
 
     dispPtr = ((TkWindow *) tkwin)->dispPtr;
     if (!dispPtr->atomInit) {
 	AtomInit(dispPtr);
     }
 
-    hPtr = Tcl_CreateHashEntry(&dispPtr->nameTable, name, &new);
-    if (new) {
+    hPtr = Tcl_CreateHashEntry(&dispPtr->nameTable, name, &isNew);
+    if (isNew) {
 	Tcl_HashEntry *hPtr2;
 	Atom atom;
 
 	atom = XInternAtom(dispPtr->display, name, False);
 	Tcl_SetHashValue(hPtr, atom);
-	hPtr2 = Tcl_CreateHashEntry(&dispPtr->atomTable, (char *) atom,
-		&new);
+	hPtr2 = Tcl_CreateHashEntry(&dispPtr->atomTable, (char*) atom, &isNew);
 	Tcl_SetHashValue(hPtr2, Tcl_GetHashKey(&dispPtr->nameTable, hPtr));
     }
     return (Atom) Tcl_GetHashValue(hPtr);
@@ -108,16 +105,15 @@ Tk_InternAtom(tkwin, name)
  *
  * Tk_GetAtomName --
  *
- *	This procedure is equivalent to XGetAtomName except that
- *	it uses the local atom cache to avoid contacting the
- *	server.
+ *	This function is equivalent to XGetAtomName except that it uses the
+ *	local atom cache to avoid contacting the server.
  *
  * Results:
- *	The return value is a character string corresponding to
- *	the atom given by "atom".  This string's storage space
- *	is static:  it need not be freed by the caller, and should
- *	not be modified by the caller.  If "atom" doesn't exist
- *	on tkwin's display, then the string "?bad atom?" is returned.
+ *	The return value is a character string corresponding to the atom given
+ *	by "atom". This string's storage space is static: it need not be freed
+ *	by the caller, and should not be modified by the caller. If "atom"
+ *	doesn't exist on tkwin's display, then the string "?bad atom?"  is
+ *	returned.
  *
  * Side effects:
  *	None.
@@ -126,11 +122,10 @@ Tk_InternAtom(tkwin, name)
  */
 
 CONST char *
-Tk_GetAtomName(tkwin, atom)
-    Tk_Window tkwin;		/* Window token;  map atom to name
-				 * relative to this window's
-				 * display. */
-    Atom atom;			/* Atom whose name is wanted. */
+Tk_GetAtomName(
+    Tk_Window tkwin,		/* Window token; map atom to name relative to
+				 * this window's display. */
+    Atom atom)			/* Atom whose name is wanted. */
 {
     register TkDisplay *dispPtr;
     register Tcl_HashEntry *hPtr;
@@ -144,10 +139,10 @@ Tk_GetAtomName(tkwin, atom)
     if (hPtr == NULL) {
 	char *name;
 	Tk_ErrorHandler handler;
-	int new, mustFree;
+	int isNew, mustFree;
 
-	handler= Tk_CreateErrorHandler(dispPtr->display, BadAtom,
-		-1, -1, (Tk_ErrorProc *) NULL, (ClientData) NULL);
+	handler = Tk_CreateErrorHandler(dispPtr->display, BadAtom, -1, -1,
+		NULL, (ClientData) NULL);
 	name = XGetAtomName(dispPtr->display, atom);
 	mustFree = 1;
 	if (name == NULL) {
@@ -155,15 +150,13 @@ Tk_GetAtomName(tkwin, atom)
 	    mustFree = 0;
 	}
 	Tk_DeleteErrorHandler(handler);
-	hPtr = Tcl_CreateHashEntry(&dispPtr->nameTable, (char *) name,
-		&new);
+	hPtr = Tcl_CreateHashEntry(&dispPtr->nameTable, name, &isNew);
 	Tcl_SetHashValue(hPtr, atom);
 	if (mustFree) {
 	    XFree(name);
 	}
 	name = Tcl_GetHashKey(&dispPtr->nameTable, hPtr);
-	hPtr = Tcl_CreateHashEntry(&dispPtr->atomTable, (char *) atom,
-		&new);
+	hPtr = Tcl_CreateHashEntry(&dispPtr->atomTable, (char *) atom, &isNew);
 	Tcl_SetHashValue(hPtr, name);
     }
     return Tcl_GetHashValue(hPtr);
@@ -186,8 +179,8 @@ Tk_GetAtomName(tkwin, atom)
  */
 
 static void
-AtomInit(dispPtr)
-    register TkDisplay *dispPtr;	/* Display to initialize. */
+AtomInit(
+    register TkDisplay *dispPtr)/* Display to initialize. */
 {
     Tcl_HashEntry *hPtr;
     Atom atom;
@@ -197,19 +190,27 @@ AtomInit(dispPtr)
     Tcl_InitHashTable(&dispPtr->atomTable, TCL_ONE_WORD_KEYS);
 
     for (atom = 1; atom <= XA_LAST_PREDEFINED; atom++) {
-	hPtr = Tcl_FindHashEntry(&dispPtr->atomTable, (char *) atom);
-	if (hPtr == NULL) {
-	    CONST char *name;
-	    int new;
+	char *name;
+	int isNew;
 
-	    name = atomNameArray[atom - 1];
-	    hPtr = Tcl_CreateHashEntry(&dispPtr->nameTable, (char *) name,
-		&new);
-	    Tcl_SetHashValue(hPtr, atom);
-	    name = Tcl_GetHashKey(&dispPtr->nameTable, hPtr);
-	    hPtr = Tcl_CreateHashEntry(&dispPtr->atomTable, (char *) atom,
-		&new);
-	    Tcl_SetHashValue(hPtr, name);
+	hPtr = Tcl_FindHashEntry(&dispPtr->atomTable, (char *) atom);
+	if (hPtr != NULL) {
+	    continue;
 	}
+
+	name = atomNameArray[atom - 1];
+	hPtr = Tcl_CreateHashEntry(&dispPtr->nameTable, name, &isNew);
+	Tcl_SetHashValue(hPtr, atom);
+	name = Tcl_GetHashKey(&dispPtr->nameTable, hPtr);
+	hPtr = Tcl_CreateHashEntry(&dispPtr->atomTable, (char *) atom, &isNew);
+	Tcl_SetHashValue(hPtr, name);
     }
 }
+
+/*
+ * Local Variables:
+ * mode: c
+ * c-basic-offset: 4
+ * fill-column: 78
+ * End:
+ */
